@@ -52,7 +52,7 @@ STATE_INIT = 0
 STATE_READY = 1
 
 
-class Server(object):
+class Connection(object):
     """
     MAPI (low level MonetDB API) connection
     """
@@ -191,8 +191,8 @@ class Server(object):
                 password = h.hexdigest()
             except ValueError, e:
                 raise NotSupportedError(e.message)
-        elif protocol != "8":
-            raise NotSupportedError("We only speak protocol v8 and v9")
+        else:
+            raise NotSupportedError("We only speak protocol v9")
 
         h = hashes.split(",")
         if "SHA1" in h:
@@ -205,11 +205,8 @@ class Server(object):
             m.update(password.encode())
             m.update(salt.encode())
             pwhash = "{MD5}" + m.hexdigest()
-        elif "crypt" in h:
-            import crypt
-            pwhash = "{crypt}" + crypt.crypt((password+salt)[:8], salt[-2:])
         else:
-            pwhash = "{plain}" + password + salt
+            raise NotSupportedError("Unsupported hash algorithms required for login: %s" % (hashes));
 
         return ":".join(["BIG", self.username, pwhash, self.language,
             self.database]) + ":"
@@ -224,9 +221,9 @@ class Server(object):
             unpacked = struct.unpack('<H', flag)[0] # unpack little endian short
             length = unpacked >> 1
             last = unpacked & 1
-            logger.debug("II: reading %i bytes, last: %s" % (length, bool(last)))
+            #logger.debug("II: reading %i bytes, last: %s" % (length, bool(last)))
             result.write(self.__getbytes(length))
-        logger.debug("RX: %s" % result.getvalue())
+        #logger.debug("RX: %s" % result.getvalue())
         return result.getvalue()
 
 
@@ -239,7 +236,7 @@ class Server(object):
                 recv = self.socket.recv(count)
                 if len(recv) == 0:
                     time.sleep(1)
-                logger.debug("II: package size: %i payload: %s" % (len(recv), recv))
+                #logger.debug("II: package size: %i payload: %s" % (len(recv), recv))
             except socket.error, error:
                 raise OperationalError(error[1])
             count -= len(recv)
@@ -257,8 +254,8 @@ class Server(object):
             if length < MAX_PACKAGE_LENGTH:
                 last = 1
             flag = struct.pack( '<H', ( length << 1 ) + last )
-            logger.debug("II: sending %i bytes, last: %s" % (length, bool(last)))
-            logger.debug("TX: %s" % data)
+            #logger.debug("II: sending %i bytes, last: %s" % (length, bool(last)))
+            #logger.debug("TX: %s" % data)
             try:
                 self.socket.send(flag)
                 self.socket.send(data)
@@ -270,3 +267,7 @@ class Server(object):
     def __del__(self):
         if self.socket:
             self.socket.close()
+
+#backwards compatiblity
+Server = Connection
+
